@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 
 use strict;
 use warnings;
@@ -7,24 +7,35 @@ use warnings;
 
 use Data::Dumper;
 use Digest::MD5 qw(md5_hex);
+use File::Path qw(make_path);
 use File::Slurp qw(read_file write_file);
+use Getopt::Long;
 use JSON::XS;
 use Sereal qw(encode_sereal decode_sereal);
 
 my $QC_DATABASE   = 'qc.dat';
 my $COVERDB       = './cover_db/';
+my $VERBOSE       = 0;
+my %PATH_REWRITES = ();
+
+GetOptions('input=s'         => \$QC_DATABASE,
+           'cover-db=s'      => \$COVERDB,
+           'verbose=i'       => \$VERBOSE,
+           'path-rewrite=s%' => \%PATH_REWRITES,
+);
+
 my $DIGESTS       = "$COVERDB/digests";
 my $STRUCTURE     = "$COVERDB/structure/";
 my $RUNS          = "$COVERDB/runs/";
 
-my $JSON          = JSON::XS->new->utf8;
+my $JSON          = JSON::XS->new->utf8->indent;
 my $DEVEL_COVER_DB_FORMAT = 'Sereal';
 $ENV{DEVEL_COVER_DB_FORMAT}
     and $DEVEL_COVER_DB_FORMAT = 'JSON';
 
 exit main();
 
-sub main() {
+sub main {
     my $data = load_data($QC_DATABASE);
 
     make_coverdb_directories();
@@ -35,13 +46,13 @@ sub main() {
 
 sub make_coverdb_directories {
     -d $COVERDB
-        or mkdir $COVERDB;
+        or make_path $COVERDB;
 
     -d $STRUCTURE
-        or mkdir $STRUCTURE;
+        or make_path $STRUCTURE;
 
     -d $RUNS
-        or mkdir $RUNS;
+        or make_path $RUNS;
 }
 
 sub load_data {
@@ -89,12 +100,17 @@ sub generate_cover_db {
     };
 
     for my $file (keys %{ $data }) {
+        my $original_filename = $file;
+        while ( my ($from, $to) = each %PATH_REWRITES ) {
+            $file =~ s/$from/$to/;
+        }
         if (!-r $file) {
-            print "Skipping $file for now. Probably an eval\n";
+            $VERBOSE and
+                print "Skipping $file for now. Probably an eval\n";
             next;
         }
 
-        my $hits              = $data->{ $file };
+        my $hits              = $data->{ $original_filename };
         my ($statement, $md5) = process_file_structure($file, $digests);
 
         $run->{count}{$file}{statement} = [ map +( $hits->{ $_ } // 0), @{ $statement } ];
